# dependency-tracker-client

DependencyTracker - the Ruby gem for the Dependency-Track API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.8.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build dependency-tracker-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./dependency-tracker-client-1.0.0.gem
```

(for development, run `gem install --dev ./dependency-tracker-client-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'dependency-tracker-client', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'dependency-tracker-client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'dependency-tracker-client'

# Setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
  # Configure Endpoint
  config.endpoint = "https://dependencytracker.local/api/"
end

api_instance = DependencyTracker::AnalysisApi.new
component = 'component_example' # String | The UUID of the component
vulnerability = 'vulnerability_example' # String | The UUID of the vulnerability
opts = {
  project: 'project_example' # String | The UUID of the project
}

begin
  #Retrieves an analysis trail
  result = api_instance.retrieve_analysis(component, vulnerability, opts)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling AnalysisApi->retrieve_analysis: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DependencyTracker::AnalysisApi* | [**retrieve_analysis**](docs/AnalysisApi.md#retrieve_analysis) | **GET** /v1/analysis | Retrieves an analysis trail
*DependencyTracker::AnalysisApi* | [**update_analysis**](docs/AnalysisApi.md#update_analysis) | **PUT** /v1/analysis | Records an analysis decision
*DependencyTracker::AnalysisApi* | [**update_global_analysis**](docs/AnalysisApi.md#update_global_analysis) | **PUT** /v1/analysis/global | Records an analysis decision
*DependencyTracker::BadgeApi* | [**get_project_vulnerabilities_badge**](docs/BadgeApi.md#get_project_vulnerabilities_badge) | **GET** /v1/badge/vulns/project/{name}/{version} | Returns current metrics for a specific project
*DependencyTracker::BadgeApi* | [**get_project_vulnerabilities_badge1**](docs/BadgeApi.md#get_project_vulnerabilities_badge1) | **GET** /v1/badge/vulns/project/{uuid} | Returns current metrics for a specific project
*DependencyTracker::BomApi* | [**export_component_as_cyclone_dx**](docs/BomApi.md#export_component_as_cyclone_dx) | **GET** /v1/bom/cyclonedx/component/{uuid} | Returns dependency metadata for a specific component in CycloneDX format
*DependencyTracker::BomApi* | [**export_components_as_cyclone_dx**](docs/BomApi.md#export_components_as_cyclone_dx) | **GET** /v1/bom/cyclonedx/components | Returns dependency metadata for all components in CycloneDX format
*DependencyTracker::BomApi* | [**export_project_as_cyclone_dx**](docs/BomApi.md#export_project_as_cyclone_dx) | **GET** /v1/bom/cyclonedx/project/{uuid} | Returns dependency metadata for a project in CycloneDX format
*DependencyTracker::BomApi* | [**is_token_being_processed**](docs/BomApi.md#is_token_being_processed) | **GET** /v1/bom/token/{uuid} | Determines if there are any tasks associated with the token that are being processed, or in the queue to be processed.
*DependencyTracker::BomApi* | [**upload_bom**](docs/BomApi.md#upload_bom) | **POST** /v1/bom | Upload a supported bill of material format document
*DependencyTracker::BomApi* | [**upload_bom1**](docs/BomApi.md#upload_bom1) | **PUT** /v1/bom | Upload a supported bill of material format document
*DependencyTracker::CalculatorApi* | [**get_cvss_scores**](docs/CalculatorApi.md#get_cvss_scores) | **GET** /v1/calculator/cvss | Returns the CVSS base score, impact sub-score and exploitability sub-score
*DependencyTracker::ComponentApi* | [**create_component**](docs/ComponentApi.md#create_component) | **PUT** /v1/component | Creates a new component
*DependencyTracker::ComponentApi* | [**delete_component**](docs/ComponentApi.md#delete_component) | **DELETE** /v1/component/{uuid} | Deletes a component
*DependencyTracker::ComponentApi* | [**get_all_components**](docs/ComponentApi.md#get_all_components) | **GET** /v1/component | Returns a list of all components
*DependencyTracker::ComponentApi* | [**get_component_by_hash**](docs/ComponentApi.md#get_component_by_hash) | **GET** /v1/component/hash/{hash} | Returns a specific component
*DependencyTracker::ComponentApi* | [**get_component_by_uuid**](docs/ComponentApi.md#get_component_by_uuid) | **GET** /v1/component/{uuid} | Returns a specific component
*DependencyTracker::ComponentApi* | [**identify_internal_components**](docs/ComponentApi.md#identify_internal_components) | **GET** /v1/component/internal/identify | Requests the identification of internal components in the portfolio
*DependencyTracker::ComponentApi* | [**update_component**](docs/ComponentApi.md#update_component) | **POST** /v1/component | Updates a component
*DependencyTracker::ConfigPropertyApi* | [**get_config_properties**](docs/ConfigPropertyApi.md#get_config_properties) | **GET** /v1/configProperty | Returns a list of all ConfigProperties for the specified groupName
*DependencyTracker::ConfigPropertyApi* | [**update_config_property**](docs/ConfigPropertyApi.md#update_config_property) | **POST** /v1/configProperty | Updates a config property
*DependencyTracker::ConfigPropertyApi* | [**update_config_property1**](docs/ConfigPropertyApi.md#update_config_property1) | **POST** /v1/configProperty/aggregate | Updates an array of config properties
*DependencyTracker::CweApi* | [**get_cwe**](docs/CweApi.md#get_cwe) | **GET** /v1/cwe/{cweId} | Returns a specific CWE
*DependencyTracker::CweApi* | [**get_cwes**](docs/CweApi.md#get_cwes) | **GET** /v1/cwe | Returns a list of all CWEs
*DependencyTracker::DefaultApi* | [**add_project_to_rule**](docs/DefaultApi.md#add_project_to_rule) | **POST** /v1/notification/rule/{ruleUuid}/project/{projectUuid} | Adds a project to a notification rule
*DependencyTracker::DefaultApi* | [**create_notification_rule**](docs/DefaultApi.md#create_notification_rule) | **PUT** /v1/notification/rule | Creates a new notification rule
*DependencyTracker::DefaultApi* | [**delete_notification_rule**](docs/DefaultApi.md#delete_notification_rule) | **DELETE** /v1/notification/rule | Deletes a notification rule
*DependencyTracker::DefaultApi* | [**get_all_notification_publishers**](docs/DefaultApi.md#get_all_notification_publishers) | **GET** /v1/notification/publisher | Returns a list of all notification publishers
*DependencyTracker::DefaultApi* | [**get_all_notification_rules**](docs/DefaultApi.md#get_all_notification_rules) | **GET** /v1/notification/rule | Returns a list of all notification rules
*DependencyTracker::DefaultApi* | [**remove_project_from_rule**](docs/DefaultApi.md#remove_project_from_rule) | **DELETE** /v1/notification/rule/{ruleUuid}/project/{projectUuid} | Removes a project from a notification rule
*DependencyTracker::DefaultApi* | [**test_smtp_publisher_config**](docs/DefaultApi.md#test_smtp_publisher_config) | **POST** /v1/notification/publisher/test/smtp | Dispatches a SMTP notification test
*DependencyTracker::DefaultApi* | [**update_notification_rule**](docs/DefaultApi.md#update_notification_rule) | **POST** /v1/notification/rule | Updates a notification rule
*DependencyTracker::DependencyApi* | [**add_dependency**](docs/DependencyApi.md#add_dependency) | **PUT** /v1/dependency | Adds one or more components as a dependency to a project
*DependencyTracker::DependencyApi* | [**get_dependencies_by_component**](docs/DependencyApi.md#get_dependencies_by_component) | **GET** /v1/dependency/component/{uuid} | Returns a list of all dependencies for a specific component
*DependencyTracker::DependencyApi* | [**get_dependencies_by_project**](docs/DependencyApi.md#get_dependencies_by_project) | **GET** /v1/dependency/project/{uuid} | Returns a list of all dependencies for a specific project
*DependencyTracker::DependencyApi* | [**remove_dependency**](docs/DependencyApi.md#remove_dependency) | **DELETE** /v1/dependency | Removes a component as a dependency from a project
*DependencyTracker::FindingApi* | [**export_findings_by_project**](docs/FindingApi.md#export_findings_by_project) | **GET** /v1/finding/project/{uuid}/export | Returns a the findings for the specified project as FPF
*DependencyTracker::FindingApi* | [**get_findings_by_project**](docs/FindingApi.md#get_findings_by_project) | **GET** /v1/finding/project/{uuid} | Returns a list of all findings for a specific project
*DependencyTracker::LdapApi* | [**add_mapping**](docs/LdapApi.md#add_mapping) | **PUT** /v1/ldap/mapping | Adds a mapping
*DependencyTracker::LdapApi* | [**delete_mapping**](docs/LdapApi.md#delete_mapping) | **DELETE** /v1/ldap/mapping/{uuid} | Removes a mapping
*DependencyTracker::LdapApi* | [**retrieve_ldap_groups**](docs/LdapApi.md#retrieve_ldap_groups) | **GET** /v1/ldap/groups | Returns the DNs of all accessible groups within the directory
*DependencyTracker::LdapApi* | [**retrieve_ldap_groups1**](docs/LdapApi.md#retrieve_ldap_groups1) | **GET** /v1/ldap/team/{uuid} | Returns the DNs of all groups mapped to the specified team
*DependencyTracker::LicenseApi* | [**get_license**](docs/LicenseApi.md#get_license) | **GET** /v1/license/{licenseId} | Returns a specific license
*DependencyTracker::LicenseApi* | [**get_license_listing**](docs/LicenseApi.md#get_license_listing) | **GET** /v1/license/concise | Returns a concise listing of all licenses
*DependencyTracker::LicenseApi* | [**get_licenses**](docs/LicenseApi.md#get_licenses) | **GET** /v1/license | Returns a list of all licenses with complete metadata for each license
*DependencyTracker::MetricsApi* | [**get_component_current_metrics**](docs/MetricsApi.md#get_component_current_metrics) | **GET** /v1/metrics/component/{uuid}/current | Returns current metrics for a specific component
*DependencyTracker::MetricsApi* | [**get_component_metrics_since**](docs/MetricsApi.md#get_component_metrics_since) | **GET** /v1/metrics/component/{uuid}/since/{date} | Returns historical metrics for a specific component from a specific date
*DependencyTracker::MetricsApi* | [**get_component_metrics_x_days**](docs/MetricsApi.md#get_component_metrics_x_days) | **GET** /v1/metrics/component/{uuid}/days/{days} | Returns X days of historical metrics for a specific component
*DependencyTracker::MetricsApi* | [**get_dependency_current_metrics**](docs/MetricsApi.md#get_dependency_current_metrics) | **GET** /v1/metrics/project/{projectUuid}/component/{componentUuid}/current | Returns current metrics for a specific dependency
*DependencyTracker::MetricsApi* | [**get_dependency_metrics_since**](docs/MetricsApi.md#get_dependency_metrics_since) | **GET** /v1/metrics/project/{projectUuid}/component/{componentUuid}/since/{date} | Returns historical metrics for a specific dependency from a specific date
*DependencyTracker::MetricsApi* | [**get_dependency_metrics_x_days**](docs/MetricsApi.md#get_dependency_metrics_x_days) | **GET** /v1/metrics/project/{projectUuid}/component/{componentUuid}/days/{days} | Returns X days of historical metrics for a specific dependency
*DependencyTracker::MetricsApi* | [**get_portfolio_current_metrics**](docs/MetricsApi.md#get_portfolio_current_metrics) | **GET** /v1/metrics/portfolio/current | Returns current metrics for the entire portfolio
*DependencyTracker::MetricsApi* | [**get_portfolio_metrics_since**](docs/MetricsApi.md#get_portfolio_metrics_since) | **GET** /v1/metrics/portfolio/since/{date} | Returns historical metrics for the entire portfolio from a specific date
*DependencyTracker::MetricsApi* | [**get_portfolio_metrics_x_days**](docs/MetricsApi.md#get_portfolio_metrics_x_days) | **GET** /v1/metrics/portfolio/{days}/days | Returns X days of historical metrics for the entire portfolio
*DependencyTracker::MetricsApi* | [**get_project_current_metrics**](docs/MetricsApi.md#get_project_current_metrics) | **GET** /v1/metrics/project/{uuid}/current | Returns current metrics for a specific project
*DependencyTracker::MetricsApi* | [**get_project_metrics_since**](docs/MetricsApi.md#get_project_metrics_since) | **GET** /v1/metrics/project/{uuid}/since/{date} | Returns historical metrics for a specific project from a specific date
*DependencyTracker::MetricsApi* | [**get_project_metrics_x_days**](docs/MetricsApi.md#get_project_metrics_x_days) | **GET** /v1/metrics/project/{uuid}/days/{days} | Returns X days of historical metrics for a specific project
*DependencyTracker::MetricsApi* | [**get_vulnerability_metrics**](docs/MetricsApi.md#get_vulnerability_metrics) | **GET** /v1/metrics/vulnerability | Returns the sum of all vulnerabilities in the database by year and month
*DependencyTracker::MetricsApi* | [**refresh_component_metrics**](docs/MetricsApi.md#refresh_component_metrics) | **GET** /v1/metrics/component/{uuid}/refresh | Requests a refresh of a specific components metrics
*DependencyTracker::MetricsApi* | [**refresh_dependency_metrics**](docs/MetricsApi.md#refresh_dependency_metrics) | **GET** /v1/metrics/project/{projectUuid}/component/{componentUuid}/refresh | Requests a refresh of a specific dependency metrics
*DependencyTracker::MetricsApi* | [**refresh_portfolio_metrics**](docs/MetricsApi.md#refresh_portfolio_metrics) | **GET** /v1/metrics/portfolio/refresh | Requests a refresh of the portfolio metrics
*DependencyTracker::MetricsApi* | [**refresh_project_metrics**](docs/MetricsApi.md#refresh_project_metrics) | **GET** /v1/metrics/project/{uuid}/refresh | Requests a refresh of a specific projects metrics
*DependencyTracker::PermissionApi* | [**add_permission_to_team**](docs/PermissionApi.md#add_permission_to_team) | **POST** /v1/permission/{permission}/team/{uuid} | Adds the permission to the specified username.
*DependencyTracker::PermissionApi* | [**add_permission_to_user**](docs/PermissionApi.md#add_permission_to_user) | **POST** /v1/permission/{permission}/user/{username} | Adds the permission to the specified username.
*DependencyTracker::PermissionApi* | [**get_all_permissions**](docs/PermissionApi.md#get_all_permissions) | **GET** /v1/permission | Returns a list of all permissions
*DependencyTracker::PermissionApi* | [**remove_permission_from_team**](docs/PermissionApi.md#remove_permission_from_team) | **DELETE** /v1/permission/{permission}/team/{uuid} | Removes the permission from the team.
*DependencyTracker::PermissionApi* | [**remove_permission_from_user**](docs/PermissionApi.md#remove_permission_from_user) | **DELETE** /v1/permission/{permission}/user/{username} | Removes the permission from the user.
*DependencyTracker::ProjectApi* | [**clone_project**](docs/ProjectApi.md#clone_project) | **PUT** /v1/project/clone | Clones a project
*DependencyTracker::ProjectApi* | [**create_project**](docs/ProjectApi.md#create_project) | **PUT** /v1/project | Creates a new project
*DependencyTracker::ProjectApi* | [**delete_project**](docs/ProjectApi.md#delete_project) | **DELETE** /v1/project/{uuid} | Deletes a project
*DependencyTracker::ProjectApi* | [**get_project**](docs/ProjectApi.md#get_project) | **GET** /v1/project/lookup | Returns a specific project by its name and version
*DependencyTracker::ProjectApi* | [**get_project1**](docs/ProjectApi.md#get_project1) | **GET** /v1/project/{uuid} | Returns a specific project
*DependencyTracker::ProjectApi* | [**get_projects**](docs/ProjectApi.md#get_projects) | **GET** /v1/project | Returns a list of all projects
*DependencyTracker::ProjectApi* | [**get_projects_by_tag**](docs/ProjectApi.md#get_projects_by_tag) | **GET** /v1/project/tag/{tag} | Returns a list of all projects by tag
*DependencyTracker::ProjectApi* | [**update_project**](docs/ProjectApi.md#update_project) | **POST** /v1/project | Updates a project
*DependencyTracker::ProjectPropertyApi* | [**create_property**](docs/ProjectPropertyApi.md#create_property) | **PUT** /v1/project/{uuid}/property | Creates a new project property
*DependencyTracker::ProjectPropertyApi* | [**delete_property**](docs/ProjectPropertyApi.md#delete_property) | **DELETE** /v1/project/{uuid}/property | Deletes a config property
*DependencyTracker::ProjectPropertyApi* | [**get_properties**](docs/ProjectPropertyApi.md#get_properties) | **GET** /v1/project/{uuid}/property | Returns a list of all ProjectProperties for the specified project
*DependencyTracker::ProjectPropertyApi* | [**update_property**](docs/ProjectPropertyApi.md#update_property) | **POST** /v1/project/{uuid}/property | Updates a project property
*DependencyTracker::RepositoryApi* | [**create_repository**](docs/RepositoryApi.md#create_repository) | **PUT** /v1/repository | Creates a new repository
*DependencyTracker::RepositoryApi* | [**delete_repository**](docs/RepositoryApi.md#delete_repository) | **DELETE** /v1/repository/{uuid} | Deletes a repository
*DependencyTracker::RepositoryApi* | [**get_repositories**](docs/RepositoryApi.md#get_repositories) | **GET** /v1/repository | Returns a list of all repositories
*DependencyTracker::RepositoryApi* | [**get_repositories_by_type**](docs/RepositoryApi.md#get_repositories_by_type) | **GET** /v1/repository/{type} | Returns repositories that support the specific type
*DependencyTracker::RepositoryApi* | [**get_repository_meta_component**](docs/RepositoryApi.md#get_repository_meta_component) | **GET** /v1/repository/latest | Attempts to resolve the latest version of the component available in the configured repositories
*DependencyTracker::RepositoryApi* | [**update_repository**](docs/RepositoryApi.md#update_repository) | **POST** /v1/repository | Updates a repository
*DependencyTracker::SearchApi* | [**search**](docs/SearchApi.md#search) | **GET** /v1/search/{query} | Processes and returns search results
*DependencyTracker::SearchApi* | [**search_via_query_string**](docs/SearchApi.md#search_via_query_string) | **GET** /v1/search | Processes and returns search results
*DependencyTracker::TeamApi* | [**create_team**](docs/TeamApi.md#create_team) | **PUT** /v1/team | Creates a new team along with an associated API key
*DependencyTracker::TeamApi* | [**delete_api_key**](docs/TeamApi.md#delete_api_key) | **DELETE** /v1/team/key/{apikey} | Deletes the specified API key
*DependencyTracker::TeamApi* | [**delete_team**](docs/TeamApi.md#delete_team) | **DELETE** /v1/team | Deletes a team
*DependencyTracker::TeamApi* | [**generate_api_key**](docs/TeamApi.md#generate_api_key) | **PUT** /v1/team/{uuid}/key | Generates an API key and returns its value
*DependencyTracker::TeamApi* | [**get_team**](docs/TeamApi.md#get_team) | **GET** /v1/team/{uuid} | Returns a specific team
*DependencyTracker::TeamApi* | [**get_teams**](docs/TeamApi.md#get_teams) | **GET** /v1/team | Returns a list of all teams
*DependencyTracker::TeamApi* | [**regenerate_api_key**](docs/TeamApi.md#regenerate_api_key) | **POST** /v1/team/key/{apikey} | Regenerates an API key by removing the specified key, generating a new one and returning its value
*DependencyTracker::TeamApi* | [**update_team**](docs/TeamApi.md#update_team) | **POST** /v1/team | Updates a team's fields including
*DependencyTracker::UserApi* | [**add_team_to_user**](docs/UserApi.md#add_team_to_user) | **POST** /v1/user/{username}/membership | Adds the username to the specified team.
*DependencyTracker::UserApi* | [**create_ldap_user**](docs/UserApi.md#create_ldap_user) | **PUT** /v1/user/ldap | Creates a new user that references an existing LDAP object.
*DependencyTracker::UserApi* | [**create_managed_user**](docs/UserApi.md#create_managed_user) | **PUT** /v1/user/managed | Creates a new user.
*DependencyTracker::UserApi* | [**delete_ldap_user**](docs/UserApi.md#delete_ldap_user) | **DELETE** /v1/user/ldap | Deletes a user.
*DependencyTracker::UserApi* | [**delete_managed_user**](docs/UserApi.md#delete_managed_user) | **DELETE** /v1/user/managed | Deletes a user.
*DependencyTracker::UserApi* | [**force_change_password**](docs/UserApi.md#force_change_password) | **POST** /v1/user/forceChangePassword | Asserts login credentials and upon successful authentication, verifies passwords match and changes users password
*DependencyTracker::UserApi* | [**get_ldap_users**](docs/UserApi.md#get_ldap_users) | **GET** /v1/user/ldap | Returns a list of all LDAP users
*DependencyTracker::UserApi* | [**get_managed_users**](docs/UserApi.md#get_managed_users) | **GET** /v1/user/managed | Returns a list of all managed users
*DependencyTracker::UserApi* | [**get_self**](docs/UserApi.md#get_self) | **GET** /v1/user/self | Returns information about the current logged in user.
*DependencyTracker::UserApi* | [**remove_team_from_user**](docs/UserApi.md#remove_team_from_user) | **DELETE** /v1/user/{username}/membership | Removes the username from the specified team.
*DependencyTracker::UserApi* | [**update_managed_user**](docs/UserApi.md#update_managed_user) | **POST** /v1/user/managed | Updates a managed user.
*DependencyTracker::UserApi* | [**update_self**](docs/UserApi.md#update_self) | **POST** /v1/user/self | Updates information about the current logged in user.
*DependencyTracker::UserApi* | [**validate_credentials**](docs/UserApi.md#validate_credentials) | **POST** /v1/user/login | Assert login credentials
*DependencyTracker::VersionApi* | [**get_version**](docs/VersionApi.md#get_version) | **GET** /version | Returns application version information
*DependencyTracker::VulnerabilityApi* | [**assign_vulnerability**](docs/VulnerabilityApi.md#assign_vulnerability) | **POST** /v1/vulnerability/source/{source}/vuln/{vulnId}/component/{component} | Assigns a vulnerability to a component
*DependencyTracker::VulnerabilityApi* | [**assign_vulnerability1**](docs/VulnerabilityApi.md#assign_vulnerability1) | **POST** /v1/vulnerability/{uuid}/component/{component} | Assigns a vulnerability to a component
*DependencyTracker::VulnerabilityApi* | [**create_vulnerability**](docs/VulnerabilityApi.md#create_vulnerability) | **PUT** /v1/vulnerability | Creates a new vulnerability
*DependencyTracker::VulnerabilityApi* | [**get_affected_project**](docs/VulnerabilityApi.md#get_affected_project) | **GET** /v1/vulnerability/source/{source}/vuln/{vuln}/projects | Returns a list of all projects affected by a specific vulnerability
*DependencyTracker::VulnerabilityApi* | [**get_all_vulnerabilities**](docs/VulnerabilityApi.md#get_all_vulnerabilities) | **GET** /v1/vulnerability | Returns a list of all vulnerabilities
*DependencyTracker::VulnerabilityApi* | [**get_vulnerabilities_by_component**](docs/VulnerabilityApi.md#get_vulnerabilities_by_component) | **GET** /v1/vulnerability/component/{ident} | Returns a list of all vulnerabilities for a specific component
*DependencyTracker::VulnerabilityApi* | [**get_vulnerabilities_by_project**](docs/VulnerabilityApi.md#get_vulnerabilities_by_project) | **GET** /v1/vulnerability/project/{uuid} | Returns a list of all vulnerabilities for a specific project
*DependencyTracker::VulnerabilityApi* | [**get_vulnerability_by_uuid**](docs/VulnerabilityApi.md#get_vulnerability_by_uuid) | **GET** /v1/vulnerability/{uuid} | Returns a specific vulnerability
*DependencyTracker::VulnerabilityApi* | [**get_vulnerability_by_vuln_id**](docs/VulnerabilityApi.md#get_vulnerability_by_vuln_id) | **GET** /v1/vulnerability/source/{source}/vuln/{vuln} | Returns a specific vulnerability
*DependencyTracker::VulnerabilityApi* | [**unassign_vulnerability**](docs/VulnerabilityApi.md#unassign_vulnerability) | **DELETE** /v1/vulnerability/source/{source}/vuln/{vulnId}/component/{component} | Removes assignment of a vulnerability from a component
*DependencyTracker::VulnerabilityApi* | [**unassign_vulnerability1**](docs/VulnerabilityApi.md#unassign_vulnerability1) | **DELETE** /v1/vulnerability/{uuid}/component/{component} | Removes assignment of a vulnerability from a component
*DependencyTracker::VulnerabilityApi* | [**update_vulnerability**](docs/VulnerabilityApi.md#update_vulnerability) | **POST** /v1/vulnerability | Updates an internal vulnerability


## Documentation for Models

 - [DependencyTracker::About](docs/About.md)
 - [DependencyTracker::Analysis](docs/Analysis.md)
 - [DependencyTracker::AnalysisComment](docs/AnalysisComment.md)
 - [DependencyTracker::AnalysisRequest](docs/AnalysisRequest.md)
 - [DependencyTracker::ApiKey](docs/ApiKey.md)
 - [DependencyTracker::BodyPart](docs/BodyPart.md)
 - [DependencyTracker::BomSubmitRequest](docs/BomSubmitRequest.md)
 - [DependencyTracker::CloneProjectRequest](docs/CloneProjectRequest.md)
 - [DependencyTracker::Component](docs/Component.md)
 - [DependencyTracker::ComponentMetrics](docs/ComponentMetrics.md)
 - [DependencyTracker::ConfigProperty](docs/ConfigProperty.md)
 - [DependencyTracker::ContentDisposition](docs/ContentDisposition.md)
 - [DependencyTracker::Cwe](docs/Cwe.md)
 - [DependencyTracker::Dependency](docs/Dependency.md)
 - [DependencyTracker::DependencyMetrics](docs/DependencyMetrics.md)
 - [DependencyTracker::DependencyRequest](docs/DependencyRequest.md)
 - [DependencyTracker::Finding](docs/Finding.md)
 - [DependencyTracker::FormDataBodyPart](docs/FormDataBodyPart.md)
 - [DependencyTracker::FormDataContentDisposition](docs/FormDataContentDisposition.md)
 - [DependencyTracker::FormDataMultiPart](docs/FormDataMultiPart.md)
 - [DependencyTracker::Framework](docs/Framework.md)
 - [DependencyTracker::IdentifiableObject](docs/IdentifiableObject.md)
 - [DependencyTracker::LdapUser](docs/LdapUser.md)
 - [DependencyTracker::License](docs/License.md)
 - [DependencyTracker::ManagedUser](docs/ManagedUser.md)
 - [DependencyTracker::MappedLdapGroup](docs/MappedLdapGroup.md)
 - [DependencyTracker::MappedLdapGroupRequest](docs/MappedLdapGroupRequest.md)
 - [DependencyTracker::MediaType](docs/MediaType.md)
 - [DependencyTracker::MultiPart](docs/MultiPart.md)
 - [DependencyTracker::NotificationPublisher](docs/NotificationPublisher.md)
 - [DependencyTracker::NotificationRule](docs/NotificationRule.md)
 - [DependencyTracker::PackageURL](docs/PackageURL.md)
 - [DependencyTracker::ParameterizedHeader](docs/ParameterizedHeader.md)
 - [DependencyTracker::Permission](docs/Permission.md)
 - [DependencyTracker::PortfolioMetrics](docs/PortfolioMetrics.md)
 - [DependencyTracker::Project](docs/Project.md)
 - [DependencyTracker::ProjectMetrics](docs/ProjectMetrics.md)
 - [DependencyTracker::ProjectProperty](docs/ProjectProperty.md)
 - [DependencyTracker::Repository](docs/Repository.md)
 - [DependencyTracker::RepositoryMetaComponent](docs/RepositoryMetaComponent.md)
 - [DependencyTracker::Score](docs/Score.md)
 - [DependencyTracker::SearchResult](docs/SearchResult.md)
 - [DependencyTracker::Tag](docs/Tag.md)
 - [DependencyTracker::Team](docs/Team.md)
 - [DependencyTracker::UserPrincipal](docs/UserPrincipal.md)
 - [DependencyTracker::Vulnerability](docs/Vulnerability.md)
 - [DependencyTracker::VulnerabilityMetrics](docs/VulnerabilityMetrics.md)
 - [DependencyTracker::VulnerableSoftware](docs/VulnerableSoftware.md)


## Documentation for Authorization


### X-Api-Key


- **Type**: API key
- **API key parameter name**: X-Api-Key
- **Location**: HTTP header

