# DependencyTracker::VulnerabilityApi

All URIs are relative to *http://localhost/api*

Method | HTTP request | Description
------------- | ------------- | -------------
[**assign_vulnerability**](VulnerabilityApi.md#assign_vulnerability) | **POST** /v1/vulnerability/source/{source}/vuln/{vulnId}/component/{component} | Assigns a vulnerability to a component
[**assign_vulnerability1**](VulnerabilityApi.md#assign_vulnerability1) | **POST** /v1/vulnerability/{uuid}/component/{component} | Assigns a vulnerability to a component
[**create_vulnerability**](VulnerabilityApi.md#create_vulnerability) | **PUT** /v1/vulnerability | Creates a new vulnerability
[**get_affected_project**](VulnerabilityApi.md#get_affected_project) | **GET** /v1/vulnerability/source/{source}/vuln/{vuln}/projects | Returns a list of all projects affected by a specific vulnerability
[**get_all_vulnerabilities**](VulnerabilityApi.md#get_all_vulnerabilities) | **GET** /v1/vulnerability | Returns a list of all vulnerabilities
[**get_vulnerabilities_by_component**](VulnerabilityApi.md#get_vulnerabilities_by_component) | **GET** /v1/vulnerability/component/{ident} | Returns a list of all vulnerabilities for a specific component
[**get_vulnerabilities_by_project**](VulnerabilityApi.md#get_vulnerabilities_by_project) | **GET** /v1/vulnerability/project/{uuid} | Returns a list of all vulnerabilities for a specific project
[**get_vulnerability_by_uuid**](VulnerabilityApi.md#get_vulnerability_by_uuid) | **GET** /v1/vulnerability/{uuid} | Returns a specific vulnerability
[**get_vulnerability_by_vuln_id**](VulnerabilityApi.md#get_vulnerability_by_vuln_id) | **GET** /v1/vulnerability/source/{source}/vuln/{vuln} | Returns a specific vulnerability
[**unassign_vulnerability**](VulnerabilityApi.md#unassign_vulnerability) | **DELETE** /v1/vulnerability/source/{source}/vuln/{vulnId}/component/{component} | Removes assignment of a vulnerability from a component
[**unassign_vulnerability1**](VulnerabilityApi.md#unassign_vulnerability1) | **DELETE** /v1/vulnerability/{uuid}/component/{component} | Removes assignment of a vulnerability from a component
[**update_vulnerability**](VulnerabilityApi.md#update_vulnerability) | **POST** /v1/vulnerability | Updates an internal vulnerability



## assign_vulnerability

> assign_vulnerability(source, vuln_id, component)

Assigns a vulnerability to a component

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
source = 'source_example' # String | The vulnerability source
vuln_id = 'vuln_id_example' # String | The vulnId
component = 'component_example' # String | The UUID of the component

begin
  #Assigns a vulnerability to a component
  api_instance.assign_vulnerability(source, vuln_id, component)
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->assign_vulnerability: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **source** | **String**| The vulnerability source | 
 **vuln_id** | **String**| The vulnId | 
 **component** | **String**| The UUID of the component | 

### Return type

nil (empty response body)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## assign_vulnerability1

> assign_vulnerability1(uuid, component)

Assigns a vulnerability to a component

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
uuid = 'uuid_example' # String | The UUID of the vulnerability
component = 'component_example' # String | The UUID of the component

begin
  #Assigns a vulnerability to a component
  api_instance.assign_vulnerability1(uuid, component)
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->assign_vulnerability1: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **uuid** | **String**| The UUID of the vulnerability | 
 **component** | **String**| The UUID of the component | 

### Return type

nil (empty response body)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## create_vulnerability

> Vulnerability create_vulnerability(opts)

Creates a new vulnerability

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
opts = {
  body: DependencyTracker::Vulnerability.new # Vulnerability | 
}

begin
  #Creates a new vulnerability
  result = api_instance.create_vulnerability(opts)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->create_vulnerability: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Vulnerability**](Vulnerability.md)|  | [optional] 

### Return type

[**Vulnerability**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_affected_project

> Array&lt;Project&gt; get_affected_project(source, vuln)

Returns a list of all projects affected by a specific vulnerability

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
source = 'source_example' # String | 
vuln = 'vuln_example' # String | 

begin
  #Returns a list of all projects affected by a specific vulnerability
  result = api_instance.get_affected_project(source, vuln)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_affected_project: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **source** | **String**|  | 
 **vuln** | **String**|  | 

### Return type

[**Array&lt;Project&gt;**](Project.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_all_vulnerabilities

> Array&lt;Vulnerability&gt; get_all_vulnerabilities

Returns a list of all vulnerabilities

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new

begin
  #Returns a list of all vulnerabilities
  result = api_instance.get_all_vulnerabilities
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_all_vulnerabilities: #{e}"
end
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**Array&lt;Vulnerability&gt;**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_vulnerabilities_by_component

> Array&lt;Vulnerability&gt; get_vulnerabilities_by_component(ident, opts)

Returns a list of all vulnerabilities for a specific component

A valid UUID of the component may be specified, or the MD5 or SHA1 hash of the component

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
ident = 'ident_example' # String | 
opts = {
  suppressed: true # Boolean | Optionally includes suppressed vulnerabilities
}

begin
  #Returns a list of all vulnerabilities for a specific component
  result = api_instance.get_vulnerabilities_by_component(ident, opts)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_vulnerabilities_by_component: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ident** | **String**|  | 
 **suppressed** | **Boolean**| Optionally includes suppressed vulnerabilities | [optional] 

### Return type

[**Array&lt;Vulnerability&gt;**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_vulnerabilities_by_project

> Array&lt;Vulnerability&gt; get_vulnerabilities_by_project(uuid, opts)

Returns a list of all vulnerabilities for a specific project

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
uuid = 'uuid_example' # String | 
opts = {
  suppressed: true # Boolean | Optionally includes suppressed vulnerabilities
}

begin
  #Returns a list of all vulnerabilities for a specific project
  result = api_instance.get_vulnerabilities_by_project(uuid, opts)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_vulnerabilities_by_project: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **uuid** | **String**|  | 
 **suppressed** | **Boolean**| Optionally includes suppressed vulnerabilities | [optional] 

### Return type

[**Array&lt;Vulnerability&gt;**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_vulnerability_by_uuid

> Vulnerability get_vulnerability_by_uuid(uuid)

Returns a specific vulnerability

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
uuid = 'uuid_example' # String | The UUID of the vulnerability

begin
  #Returns a specific vulnerability
  result = api_instance.get_vulnerability_by_uuid(uuid)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_vulnerability_by_uuid: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **uuid** | **String**| The UUID of the vulnerability | 

### Return type

[**Vulnerability**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_vulnerability_by_vuln_id

> Vulnerability get_vulnerability_by_vuln_id(source, vuln)

Returns a specific vulnerability

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
source = 'source_example' # String | 
vuln = 'vuln_example' # String | 

begin
  #Returns a specific vulnerability
  result = api_instance.get_vulnerability_by_vuln_id(source, vuln)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->get_vulnerability_by_vuln_id: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **source** | **String**|  | 
 **vuln** | **String**|  | 

### Return type

[**Vulnerability**](Vulnerability.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## unassign_vulnerability

> unassign_vulnerability(source, vuln_id, component)

Removes assignment of a vulnerability from a component

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
source = 'source_example' # String | The vulnerability source
vuln_id = 'vuln_id_example' # String | The vulnId
component = 'component_example' # String | The UUID of the component

begin
  #Removes assignment of a vulnerability from a component
  api_instance.unassign_vulnerability(source, vuln_id, component)
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->unassign_vulnerability: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **source** | **String**| The vulnerability source | 
 **vuln_id** | **String**| The vulnId | 
 **component** | **String**| The UUID of the component | 

### Return type

nil (empty response body)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## unassign_vulnerability1

> unassign_vulnerability1(uuid, component)

Removes assignment of a vulnerability from a component

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
uuid = 'uuid_example' # String | The UUID of the vulnerability
component = 'component_example' # String | The UUID of the component

begin
  #Removes assignment of a vulnerability from a component
  api_instance.unassign_vulnerability1(uuid, component)
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->unassign_vulnerability1: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **uuid** | **String**| The UUID of the vulnerability | 
 **component** | **String**| The UUID of the component | 

### Return type

nil (empty response body)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## update_vulnerability

> Project update_vulnerability(opts)

Updates an internal vulnerability

### Example

```ruby
# load the gem
require 'dependency-tracker-client'
# setup authorization
DependencyTracker.configure do |config|
  # Configure API key authorization: X-Api-Key
  config.api_key['X-Api-Key'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Api-Key'] = 'Bearer'
end

api_instance = DependencyTracker::VulnerabilityApi.new
opts = {
  body: DependencyTracker::Vulnerability.new # Vulnerability | 
}

begin
  #Updates an internal vulnerability
  result = api_instance.update_vulnerability(opts)
  p result
rescue DependencyTracker::ApiError => e
  puts "Exception when calling VulnerabilityApi->update_vulnerability: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Vulnerability**](Vulnerability.md)|  | [optional] 

### Return type

[**Project**](Project.md)

### Authorization

[X-Api-Key](../README.md#X-Api-Key)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

